@@ -38,7 +38,7 @@ ERROR_TYPE = Literal['DateTime', 'MissingDevices', 'NonNumeric', 'MissingRequire
 
 PROCESS_STATUS = Literal['ActionRequired', 'Failed']
 
-MAPPING_ENTITIES = Literal['Installations', 'Devices/Sensors', 'Readings', 'Work Orders']
+MAPPING_ENTITIES = Literal['Installations', 'Devices/Sensors', 'Readings', 'Work Orders', 'Signals']
 
 WORK_ORDER_CATEGORY = Literal['Preventative Maintenance', 'Tenant Request']
 
