@@ -129,7 +129,8 @@ def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type:
         logger.error("You must call initialize() before using API.")
         return False
 
-    if (api_inputs.data_feed_id == '00000000-0000-0000-0000-000000000000' or api_inputs.data_feed_file_status_id == '00000000-0000-0000-0000-000000000000'):
+    if (api_inputs.data_feed_id == '00000000-0000-0000-0000-000000000000' or
+            api_inputs.data_feed_file_status_id == '00000000-0000-0000-0000-000000000000'):
         logger.error("Post Errors can only be called in Production.")
         return False
 
@@ -151,7 +152,9 @@ def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type:
     url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/DataFeedErrors/" + str(error_type) \
         + "/" + str(api_inputs.data_feed_id) + "/" + str(api_inputs.data_feed_file_status_id)
 
-    response = requests.post(url, data=json.dumps(json.loads(errors_df.to_json(orient='table'))['data']), headers=headers)
+    response = requests.post(url,
+                             data=json.dumps(json.loads(errors_df.to_json(orient='table'))['data']),
+                             headers=headers)
 
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
