@@ -21,7 +21,7 @@ consoleHandler = logging.StreamHandler(stream=sys.stdout)
 consoleHandler.setLevel(logging.INFO)
 
 logger.addHandler(consoleHandler)
-formatter = logging.Formatter('%(asctime)s  %(name)s.%(funcName)s  %(levelname)s: %(message)s',
+formatter = logging.Formatter('%(asctime)s  switch_api.%(module)s.%(funcName)s  %(levelname)s: %(message)s',
                               datefmt='%Y-%m-%dT%H:%M:%S')
 consoleHandler.setFormatter(formatter)
 
@@ -132,7 +132,6 @@ def _timezone_offsets(api_inputs: ApiInputs, date_from: datetime.date, date_to:
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    print(payload)
     url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/TimeZoneOffsets"
     response = requests.post(url, json=payload, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
