@@ -254,8 +254,10 @@ def get_device_sensors(api_inputs: ApiInputs, include_tag_groups: Union[list, bo
     df : pandas.DataFrame
 
     """
-    if (include_tag_groups is True or type(include_tag_groups) == list) and (include_metadata_keys is True or type(include_metadata_keys) == list):
-        logger.exception('Tags and Metadata cannot be returned in a single call. Please set either include_tag_groups or include_metadata_keys to False. ')
+    if (include_tag_groups is True or type(include_tag_groups) == list) and \
+            (include_metadata_keys is True or type(include_metadata_keys) == list):
+        logger.exception('Tags and Metadata cannot be returned in a single call. Please set either include_tag_groups '
+                         'or include_metadata_keys to False. ')
         return
 
     if top_count is None:
@@ -502,6 +504,7 @@ def get_tag_groups(api_inputs: ApiInputs):
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
+    df.columns = ['TagGroup']
 
     return df
 
