@@ -180,7 +180,7 @@ def upsert_device_sensors(df: pandas.DataFrame, api_inputs: ApiInputs, tag_colum
         upsert_data(slices_data_frame, api_inputs=api_inputs, key_columns=['DeviceId'], table_name='DeviceSensorSlices',
                     is_slices_table=True)
 
-    _adx_support(api_inputs=api_inputs, build_sensors=True)
+    # _adx_support(api_inputs=api_inputs, build_sensors=True)
     upsert_response_df.columns = _column_name_cap(columns=upsert_response_df.columns)
 
     logger.info("Ingestion Complete. ")
@@ -297,7 +297,7 @@ def upsert_sites(df: pandas.DataFrame, api_inputs: ApiInputs, tag_columns: list
         upsert_data(slices_data_frame, api_inputs=api_inputs, key_columns=['InstallationId'],
                     table_name='InstallationSlices', is_slices_table=True)
 
-    _adx_support(api_inputs=api_inputs, build_sites=True)
+    # _adx_support(api_inputs=api_inputs, build_sites=True)
     logger.info("Ingestion complete. ")
 
     return 'Ok'
