@@ -431,6 +431,8 @@ class Automation:
             base_class = 'LogicModuleTask'
         elif issubclass(type(task), AnalyticsTask):
             base_class = 'AnalyticsTask'
+        elif issubclass(type(task), QueueTask):
+            base_class = 'QueueTask'
 
         if base_class == '':
             logger.error(
